@@ -30,6 +30,7 @@
 #include "contact-pin.h"
 #include "filtered-pinned-contacts-proxy-model.h"
 #include "telepathy-manager.h"
+#include "mainlogmodel.h"
 
 #include <TelepathyQt/PendingChannelRequest>
 #include "KTp/types.h"
@@ -54,20 +55,30 @@ void QmlPlugins::registerTypes(const char *uri)
     qmlRegisterType<KTp::AccountsListModel> (uri, 0, 1, "AccountsListModel");
 
     qmlRegisterType<ConversationsModel> (uri, 0, 1, "ConversationsModel");
-    qmlRegisterType<Conversation>(uri, 0, 1, "Conversation");
     qmlRegisterType<PinnedContactsModel>(uri, 0, 1, "PinnedContactsModel");
     qmlRegisterType<ContactPin>(uri, 0, 1, "ContactPin");
     qmlRegisterType<FilteredPinnedContactsProxyModel>(uri, 0, 1, "FilteredPinnedContactsProxyModel");
     qmlRegisterType<KTp::GlobalPresence> (uri, 0, 1, "GlobalPresence");
     qmlRegisterType<KTp::PresenceModel> (uri, 0, 1, "PresenceModel");
+    qmlRegisterType<MainLogModel> (uri, 0, 1, "MainLogModel");
 
     qmlRegisterUncreatableType<MessagesModel> (uri, 0, 1, "MessagesModel",
         QLatin1String("It will be created once the conversation is created"));
 
+#if QT_VERSION < QT_VERSION_CHECK(5, 14, 0)
     qmlRegisterType<TelepathyManager>();
-    qmlRegisterType<ConversationsModel>();
+#else
+    qmlRegisterAnonymousType<TelepathyManager>(uri, 0);
+#endif
+    qmlRegisterUncreatableType<ConversationsModel>(uri, 0, 1, "Conversation",
+        QStringLiteral("Conversation type cannot be created from QML"));
+#if QT_VERSION < QT_VERSION_CHECK(5, 14, 0)
     qmlRegisterType<Tp::PendingChannelRequest>();
     qmlRegisterType<Tp::PendingOperation>();
+#else
+    qmlRegisterAnonymousType<Tp::PendingChannelRequest>(uri, 0);
+    qmlRegisterAnonymousType<Tp::PendingOperation>(uri, 0);
+#endif
     qRegisterMetaType<Tp::Presence>();
     qRegisterMetaType<KTp::Presence>();
     qRegisterMetaType<Tp::AccountManagerPtr>();
